#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Copyright 2020 University of Liège
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


## NACA 0012 airfoil configuration file for flow polar script
# Adrien Crovato

def getParam():
    import os.path
    from fwk.wutils import parseargs
    p = {}
    # Arguments
    args = parseargs()
    p['Threads'] = args.k
    p['Verb'] = args.verb
    # Input/Output
    p['File'] = os.path.join(os.path.abspath(os.path.dirname(__file__)), '../models/n0012.geo') # Input file containing the model
    p['Pars'] = {'xLgt' : 5, 'yLgt' : 5, 'msF' : 1.0, 'msTe' : 0.01, 'msLe' : 0.005} # Parameters for input file model
    p['Dim'] = 2 # Problem dimension
    p['Format'] = 'vtk' # Save format (vtk or gmsh)
    # Markers
    p['Fluid'] = 'field' # Name of physical group containing the fluid
    p['Farfield'] = ['upstream', 'farfield', 'downstream'] # LIST of name of physical groups containing the farfield boundaries (upstream/downstream should be first/last element)
    p['Wing'] = 'airfoil' # Name of physical group containing the airfoil body
    p['Wake'] = 'wake' # Name of physical group containing the wake
    p['Te'] =  'te' # Name of physical group containing the trailing edge
    # Freestream
    p['M_inf'] = 0.3 # Freestream Mach number
    p['AoA_begin'] = -3. # Freestream angle of attack (begin)
    p['AoA_end'] = 3. # Freestream angle of attack (end)
    p['AoA_step'] = 1. # Freestream angle of attack (step)
    # Geometry
    p['S_ref'] = 1. # Reference surface length (c_ref for 2D)
    p['c_ref'] = 1. # Reference chord length
    p['x_ref'] = 0.25 # Reference point for moment computation (x)
    p['y_ref'] = 0. # Reference point for moment computation (y)
    p['z_ref'] = 0. # Reference point for moment computation (z)
    # Numerical
    p['LSolver'] = 'GMRES' # Linear solver (PARDISO, GMRES, or MUMPS)
    p['Rel_tol'] = 1e-6 # Relative tolerance on solver residual
    p['Abs_tol'] = 1e-8 # Absolute tolerance on solver residual
    p['Max_it'] = 20 # Solver maximum number of iterations
    return p

def main():
    # Script call
    import dart.api.internal.polar as p
    polar = p.Polar(getParam())
    polar.run()
    polar.disp()

if __name__ == "__main__":
    main()
